# Gitea with Tailscale Integration

![Gitea with Tailscale](https://about.gitea.com/gitea-text.svg "Gitea")

This project sets up a Gitea instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Gitea instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-gitea/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
├── gitea/
|   └── data/         # gitea configuration files
└── postgres/
    └── data/         # gitea configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-gitea
   cd ts-gitea
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data gitea/data postgres/data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure Gitea **OPTIONAL**
    - See https://docs.gitea.com/ for configuration options

5. Start the Services
    ```bash
    docker-compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login

## Services

### gitea-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: gitea-ts
- Hostname: gitea
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### gitea

- Depends on gitea-ts and gitea-db service

### gitea-gb

- Depends on gitea-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://gitea.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://gitea.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs gitea-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment the Docker socket volume mapping in the service to enable Docker integrations:
    ```yaml
    - /var/run/docker.sock:/var/run/docker.sock
    ```
- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 3000:3000
    ```
- Stopping the Services
    ```bash
    docker-compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs gitea-ts
    docker logs gitea-db
    docker logs gitea
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The Gitea service uses the Tailscale service's network stack via `network_mode: service:gitea-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Gitea documentation: https://docs.gitea.com/
    - Gitea repository: https://github.com/go-gitea/gitea